==> haskell-tls-session-manager-0.0.0.2-33-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tls-session-manager
version: 0.0.0.2
id: tls-session-manager-0.0.0.2-5Jo96PKhPthC4pfm1gU5hq
key: tls-session-manager-0.0.0.2-5Jo96PKhPthC4pfm1gU5hq
license: BSD3
maintainer: kazu@iij.ad.jp
synopsis: In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance
category: Web
author: Kazu Yamamoto
exposed: True
indefinite: False
exposed-modules:
    Network.TLS.SessionManager
hidden-modules: Network.TLS.Imports
abi: d4e323cbcce9b7fb145062590b8a6a65
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tls-session-manager-0.0.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/tls-session-manager-0.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tls-session-manager-0.0.0.2
hs-libraries: HStls-session-manager-0.0.0.2-5Jo96PKhPthC4pfm1gU5hq
depends:
    base-4.10.1.0 auto-update-0.1.4-DRogbfFYNQeJCAE3NJ8IZH
    clock-0.7.2-HOYfHHJ3W4Qjx04GjA0Jy
    psqueues-0.2.5.0-DiO9NlnIaXxJibuqtNvjpK
    tls-1.4.1-Lsy232WKSMT3uVlhHlSC6U
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             auto-update-0.1.4-DRogbfFYNQeJCAE3NJ8IZH=6fd036e4df2b37d21e0a3b20828863aa
             clock-0.7.2-HOYfHHJ3W4Qjx04GjA0Jy=01c820dbfea727c150599d4a04cd30b6
             psqueues-0.2.5.0-DiO9NlnIaXxJibuqtNvjpK=cfdacc9656319a03921b853eca2b760f
             tls-1.4.1-Lsy232WKSMT3uVlhHlSC6U=02f1684030cafaa79f7a4bcc201deb5d
haddock-interfaces: /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock
haddock-html: /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tls-session-manager-0.0.0.2-34-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tls-session-manager
version: 0.0.0.2
id: tls-session-manager-0.0.0.2-Dd1n1QhrTSP5SHQsShduEd
key: tls-session-manager-0.0.0.2-Dd1n1QhrTSP5SHQsShduEd
license: BSD3
maintainer: kazu@iij.ad.jp
synopsis: In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance
category: Web
author: Kazu Yamamoto
exposed: True
indefinite: False
exposed-modules:
    Network.TLS.SessionManager
hidden-modules: Network.TLS.Imports
abi: 2b72acdca0c901a8959b8fb94c8f4261
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tls-session-manager-0.0.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/tls-session-manager-0.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tls-session-manager-0.0.0.2
hs-libraries: HStls-session-manager-0.0.0.2-Dd1n1QhrTSP5SHQsShduEd
depends:
    base-4.10.1.0 auto-update-0.1.4-DRogbfFYNQeJCAE3NJ8IZH
    clock-0.7.2-HOYfHHJ3W4Qjx04GjA0Jy
    psqueues-0.2.6.0-CuH2X37hfOrBrbUHv9iCl3
    tls-1.4.1-Lsy232WKSMT3uVlhHlSC6U
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             auto-update-0.1.4-DRogbfFYNQeJCAE3NJ8IZH=6fd036e4df2b37d21e0a3b20828863aa
             clock-0.7.2-HOYfHHJ3W4Qjx04GjA0Jy=01c820dbfea727c150599d4a04cd30b6
             psqueues-0.2.6.0-CuH2X37hfOrBrbUHv9iCl3=edf4922c3695a04de8ee344bff49e74c
             tls-1.4.1-Lsy232WKSMT3uVlhHlSC6U=02f1684030cafaa79f7a4bcc201deb5d
haddock-interfaces: /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock
haddock-html: /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
